%Created by J.T.B. Overvelde - 18 April 2012
%Master's thesis - The Moving Noda Approach in Topology Optimization
%http://www.overvelde.com
%
%Plots the nodal distribution, displacement and stress.

function PlotSome(PlotMeshYN,PlotResultYN,ug,sg)

GlobalConst

tic %plot mesh timer

if PlotMeshYN==1
    %Plot the initial configuration
    figure, hold on
    x=[nodes.x]';
    plot(x(:,1),x(:,2),'o','color','b','linewidth',2)
    set(gca,'XTick',[-1;pCon.Lx])
    set(gca,'XTickLabel',['0';'L'])
    set(gca,'YTick',[-pCon.Ly/2;0;pCon.Ly/2])
    set(gca,'YTickLabel',['-D/2';' 0  ';' D/2'])
    set(gca,'fontsize',14)
    axis([-0.001*pCon.Lx +1.001*pCon.Lx -1.001*pCon.Ly/2 1.001*pCon.Ly/2])
end

time1=toc; %Plot mesh timer
disp([num2str(time1),' seconds to plot the problem'])
tic %Plot solution timer

%plot the deformed shape and stresses
%plot the timoshenko beam analytical solution
if PlotResultYN==1
    
    figure, hold on
    x=[nodes.x]';
    ua=zeros(mCon.n,2);
    sa=zeros(mCon.n,3);
    for i=1:mCon.n
        [ua(i,:) ea sa(i,:)]=AnalSol(x(i,:));
    end
    plot(x(:,1)+ug(:,1),x(:,2)+ug(:,2),'*','color','g')
    plot(x(:,1)+ua(:,1),x(:,2)+ua(:,2),'o','color','r')
    
    xm=zeros(sqrt(mCon.n)); ym=xm; sxm=xm; sym=xm; sxym=xm;
    uxm=xm; uym=xm;
    rep=0;
    for i=1:mCon.nx
        for j=1:mCon.ny
            rep=rep+1;
            xm(i,j)=nodes(rep).x(1);
            ym(i,j)=nodes(rep).x(2);
            sxm(i,j)=sg(rep,1);
            sym(i,j)=sg(rep,2);
            sxym(i,j)=sg(rep,3);
            uxm(i,j)=ug(rep,1);
            uym(i,j)=ug(rep,2);
        end
    end
    
    figure
    contourf(xm,ym,uxm,10), colorbar
    set(gca,'XTick',[0;pCon.Lx])
    set(gca,'XTickLabel',['0';'L'])
    set(gca,'YTick',[-pCon.Ly/2;0;pCon.Ly/2])
    set(gca,'YTickLabel',['-D/2';'   0';' D/2'])
    set(gca,'fontsize',14)
    caxis([min(min(uxm)) max(max(uxm))])
    
    figure
    contourf(xm,ym,uym,10), colorbar
    set(gca,'XTick',[0;pCon.Lx])
    set(gca,'XTickLabel',['0';'L'])
    set(gca,'YTick',[-pCon.Ly/2;0;pCon.Ly/2])
    set(gca,'YTickLabel',['-D/2';'   0';' D/2'])
    set(gca,'fontsize',14)
    caxis([min(min(uym)) max(max(uym))])
    
    figure
    contourf(xm,ym,sxm,10), colorbar
    set(gca,'XTick',[0;pCon.Lx])
    set(gca,'XTickLabel',['0';'L'])
    set(gca,'YTick',[-pCon.Ly/2;0;pCon.Ly/2])
    set(gca,'YTickLabel',['-D/2';'   0';' D/2'])
    set(gca,'fontsize',14)
    caxis([min(min(sxm)) max(max(sxm))])
    
    figure
    contourf(xm,ym,sym,10), colorbar
    set(gca,'XTick',[0;pCon.Lx])
    set(gca,'XTickLabel',['0';'L'])
    set(gca,'YTick',[-pCon.Ly/2;0;pCon.Ly/2])
    set(gca,'YTickLabel',['-D/2';'   0';' D/2'])
    set(gca,'fontsize',14)
    caxis([min(min(sym)) max(max(sym))])
    
    figure
    contourf(xm,ym,sxym,10), colorbar
    set(gca,'XTick',[0;pCon.Lx])
    set(gca,'XTickLabel',['0';'L'])
    set(gca,'YTick',[-pCon.Ly/2;0;pCon.Ly/2])
    set(gca,'YTickLabel',['-D/2';'   0';' D/2'])
    set(gca,'fontsize',14)
    caxis([min(min(sxym)) max(max(sxym))])
end

time2=toc; %plot solution timer
disp([num2str(time2),' seconds to plot the solution'])
